# Generated by Django 4.1.3 on 2022-12-26 04:14

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("djf_surveys", "0010_model_translation"),
    ]

    operations = [
        migrations.AlterField(
            model_name="question",
            name="key",
            field=models.CharField(
                blank=True,
                help_text="Unique key for this question, fill in the blank if you want to use for automatic generation.",
                max_length=225,
                null=True,
                unique=True,
                verbose_name="key",
            ),
        ),
    ]
