# Generated by Django 2.2.24 on 2022-08-03 02:27

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djf_surveys', '0008_auto_20220721_0935'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='answer',
            options={'ordering': ['question__ordering']},
        ),
        migrations.AlterModelOptions(
            name='question',
            options={'ordering': ['ordering']},
        ),
        migrations.AddField(
            model_name='question',
            name='key',
            field=models.CharField(blank=True, help_text='unique key for this question, fill in the blank if you want to generate automatically', max_length=225, null=True, unique=True),
        ),
    ]
