.rating__star {
    cursor: pointer;
}

.rating_active {
    width: 50px;
    height: 50px;
    background-size: contain;
    background-image: url("../images/star-fill.png");
}

.rating_inactive {
    width: 50px;
    height: 50px;
    background-size: contain;
    background-image: url("../images/star-border.png");
}
